/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import javax.swing.*;
import java.awt.*;
import java.util.Vector;
import java.awt.event.*;
import javax.swing.event.*;
import javax.swing.text.*;

public class ConfigurationDisplay extends AbstractButton implements ActionListener{
	boolean contractNobleCore = true;
	ElectronConfiguration displayConfig;
	Vector<JToggleButton> buttons;
	int nobleNumber;
	JToolBar bar = new JToolBar();
	JLabel term;

	public ConfigurationDisplay() {
		super();
		setLayout(new BoxLayout(this, BoxLayout.LINE_AXIS));
		buttons = new Vector<JToggleButton>();
		displayConfig = new ElectronConfiguration();
		nobleNumber = 0;
	}

	public void setContractCore(boolean contract) {
		contractNobleCore = contract;
	}

	public int getNobleNumber() {
		return nobleNumber;
	}

	public void setConfiguration(ElectronConfiguration config) {
		removeAll();
		bar = new JToolBar();
		bar.setFloatable(false);
	//	bar.setRollover(true);
		bar.setBackground(null);

		ElectronConfiguration newDisplayConfig = (ElectronConfiguration)config.clone();
		
		nobleNumber = newDisplayConfig.getNobleCoreNumber();
		if (contractNobleCore && nobleNumber > 0) {
			newDisplayConfig.removeCore(nobleNumber);
			bar.add(Box.createRigidArea(new Dimension(3,0)));
			bar.add(new JLabel("[" + ElementsData.getAbbreviation(nobleNumber) + "] "));
		}

		Vector<JToggleButton> newButtons = new Vector<JToggleButton>();
		JToggleButton subshellButton;
		ElectronSubshell subshell;
		int j;
		for (int i=0; i<newDisplayConfig.size(); i++) {
			subshell = newDisplayConfig.getSubshellAt(i);
			subshellButton = new JToggleButton("<html>" + subshell.toHTMLString() + "</html>");
			bar.add(subshellButton);			
			subshellButton.setMargin(new Insets(0,0,0,0));
			subshellButton.setFocusPainted(false);
			subshellButton.setMinimumSize(subshellButton.getPreferredSize());
			subshellButton.setMaximumSize(subshellButton.getPreferredSize());
			if ((j = displayConfig.indexOf(subshell)) >= 0)
				subshellButton.setSelected((buttons.elementAt(j)).isSelected());
			subshellButton.addActionListener(this);
			newButtons.add(subshellButton);
		}
		buttons = newButtons;
		displayConfig = newDisplayConfig;

		bar.add(Box.createRigidArea(new Dimension(3,0)));
		bar.add(term = new JLabel("<html>" + displayConfig.getTerm().toHTMLString() + "</html>"));
		bar.add(Box.createHorizontalGlue());
		add(bar);
		validate();
		JComponent parent = (JComponent)getParent();
		if (parent != null) parent.repaint();
		Dimension size = getSize();
		if (size.height != 0) {
			setMaximumSize(getSize());
			setPreferredSize(getSize());
			setMinimumSize(getSize());
		}
		fireActionPerformed(new ActionEvent(this,0,""));
	}

	public void scaleTextSize() {
		JComponent parent = (JComponent)getParent();
		Dimension size;
		Dimension maxSize = this.getParent().getParent().getSize();
		Font font = buttons.get(0).getFont(), newfont;
		for (float s=font.getSize(); s>5.0f; s=s-1.0f) {
			newfont = font.deriveFont(s);
			for (JToggleButton button : buttons) {
				button.setFont(newfont);
			}
			term.setFont(newfont);
			validate();
			size = bar.getSize();
			if(size.getWidth()<=maxSize.getWidth() && size.getHeight()<=maxSize.getHeight()) break;
		}
	}

	public void selectOutsideCore() {
		ElectronConfiguration nobleConfig = new ElectronConfiguration(nobleNumber);
		for (int i=0; i<buttons.size(); i++)
			(buttons.elementAt(i)).setSelected(!nobleConfig.containsShell(displayConfig.getSubshellAt(i)));
	}

	public void selectOpenShells() {
		for (int i=0; i<displayConfig.size(); i++)
			if (!displayConfig.getSubshellAt(i).isFull()) 
				(buttons.elementAt(i)).setSelected(true);
	}

	public String[] getSubshellsToShow() {
		Vector<String> shellStrings = new Vector<String>();
		for (int i=0; i<buttons.size(); i++) {
			if ((buttons.elementAt(i)).isSelected())
				shellStrings.add(displayConfig.getSubshellAt(i).subshellString());
		}
		return shellStrings.toArray(new String[0]);
	}
	
	// if a button is pressed, notify listeners
	public void actionPerformed(ActionEvent event) {
		fireActionPerformed(new ActionEvent(this, event.getID(), event.getActionCommand()));	
	}
}
