/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import javax.swing.table.*;
import java.util.*;

public class DataTableModel extends DefaultTableModel {
	public DataTableModel() {
		super();
	}
	
	public void clearData() {
		for (int row=getRowCount()-1; row>=0; row--) {
			removeRow(row);
		}
	}

	public double[] getColumnData(String name) {
		double[] data = new double[getRowCount()];
		int col = findColumn(name);
		for (int row=0; row<getRowCount(); row++) {
			data[row] = doubleValue(getValueAt(row,col));
		}
		return data;
	}

	public String[] getRowNames() {
		String[] data = new String[getRowCount()];
		for (int row=0; row<getRowCount(); row++) {
			data[row] = (String) getValueAt(row,0);
		}
		return data;
	}

	public Class getColumnClass(int	c) {
		Object obj = getValueAt(0,c);
		if (getRowCount() > 0) {
			if (obj instanceof String) return String.class;
			if (obj instanceof Double) return Double.class;
		}
		return String.class;
	}

	public boolean isCellEditable(int row, int col) {
		return false;
	}

	public void setValueAt(Object value, int row, String colName) {
		setValueAt(value,row,findColumn(colName));
	}

	public void setValueAt(double value, int row, String colName) {
		setValueAt(new Double(value), row, colName);
	}

	public void setValueAt(double value, int row, int col) {
		setValueAt(new Double(value), row, col);
	}

	public void addRow() {
		super.addRow(new Vector());
	}

	double doubleValue(Object o) {
		Double d = (Double) o;
		return d.doubleValue();
	}
}
