/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

public class ElectronSubshell implements Comparable {
	public static String[] lValues = {"s", "p", "d", "f", "g"};
	int n, j, electrons;
	
	public ElectronSubshell(int n, int j) {
		this.n = n;
		this.j = j;
		electrons = 0;
	}

	public ElectronSubshell(String str) {
		String subshellString = str.trim();
		int len = subshellString.length();
		n = Integer.valueOf(subshellString.substring(0,len-1)).intValue();
		j = fromSpecNotation(subshellString.substring(len-1,len));
		electrons = 0;
	}

	public Object clone() {
		ElectronSubshell c = new ElectronSubshell(n,j);
		c.addElectrons(electrons);
		return c;
	}

	public boolean isEmpty() {
		return electrons == 0;
	}

	public boolean isFull() {
		return electrons == 2*(2*j+1);	
	}

	public void addElectron() throws ShellException {
		if (isFull())
			throw new ShellException(ShellException.FULL);
		electrons++;
	}

	public void removeElectron() throws ShellException {
		if (isEmpty())
			throw new ShellException(ShellException.EMPTY);
		electrons--;
	}

	public void addElectrons(int electrons) {
		this.electrons += electrons;
	}

	public int compareTo(Object obj) {
		ElectronSubshell shell = (ElectronSubshell) obj; 
		if (this.n < shell.n) return -1;
		if (this.n > shell.n) return 1;
		if (this.j < shell.j) return -1;
		if (this.j > shell.j) return 1;
		return 0;
	}

	public boolean equals(Object obj) {
		ElectronSubshell s = (ElectronSubshell) obj;
		if (n == s.n && j == s.j && electrons == s.electrons) return true;
		return false;
	}

	public String toString() {
		return String.valueOf(n) + toSpecNotation(j) + "(" + String.valueOf(electrons) + ")";
	}

	public String subshellString() {
		return String.valueOf(n) + toSpecNotation(j);
	}

	public String toHTMLString() {
		return String.valueOf(n) + toSpecNotation(j) + "<sup>" + String.valueOf(electrons) + "</sup>";
	}

	static String toSpecNotation(int j) {
		switch (j) {
			case 0: return "s";
			case 1: return "p";
			case 2: return "d";
		}
		char specChar = (char) ('c' + j);
		return new Character(specChar).toString();
	}

	static int fromSpecNotation(String j) {
		char jChar = j.charAt(0);
		if (jChar == 's') return 0;
		if (jChar == 'p') return 1;
		if (jChar == 'd') return 2;
		return (jChar - 'c');
	}
}
