/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

public class ElementsData {
	
	public static String getName(int atomicNumber) {
		return elementNames[atomicNumber-1];
	}

	public static String getAbbreviation(int atomicNumber) {
		return abbreviations[atomicNumber-1];
	}

	public static int[][] getGroundState(int atomicNumber) {
		return groundStates[atomicNumber-1];
	}

	public static String getTerm(int atomicNumber) {
		return terms[atomicNumber-1];
	}

	public final static String[] elementNames = {"Hydrogen", "Helium", "Lithium", "Beryllium", "Boron", "Carbon", "Nitrogen", "Oxygen", "Fluorine", "Neon", "Sodium", "Magnesium", 
		 "Aluminium", "Silicon", "Phosphorus", "Sulfur", "Chlorine", "Argon", "Potassium", "Calcium", "Scandium", "Titanium", "Vanadium", 
		 "Chromium", "Manganese", "Iron", "Cobalt", "Nickel", "Copper", "Zinc", "Gallium", "Germanium", "Arsenic", "Selenium", "Bromine", 
		 "Krypton", "Rubidium", "Strontium", "Yttrium", "Zirconium", "Niobium", "Molybdenum", "Technetium", "Ruthenium", "Rhodium", 
		 "Palladium", "Silver", "Cadmium", "Indium", "Tin", "Antimony", "Tellurium", "Iodine", "Xenon", "Caesium", "Barium", "Lanthanum", 
		 "Cerium", "Praseodymium", "Neodymium", "Promethium", "Samarium", "Europium", "Gadolinium", "Terbium", "Dysprosium", "Holmium", 
		 "Erbium", "Thulium", "Ytterbium", "Lutetium", "Hafnium", "Tantalum", "Tungsten", "Rhenium", "Osmium", "Iridium", "Platinum", "Gold", 
		 "Mercury", "Thallium", "Lead", "Bismuth", "Polonium", "Astatine", "Radon", "Francium", "Radium", "Actinium", "Thorium", 
		 "Protactinium", "Uranium", "Neptunium", "Plutonium", "Americium", "Curium", "Berkelium", "Californium", "Einsteinium", "Fermium", 
		 "Mendelevium", "Nobelium", "Lawrencium", "Rutherfordium", "Dubnium", "Seaborgium", "Bohrium", "Hassium", "Meitnerium", "Ununnilium", 
		 "Unununium", "Ununbium"};

	public final static String[] abbreviations = {"H", "He", "Li", "Be", "B", "C", "N", "O", "F", "Ne", "Na", "Mg", "Al", "Si", "P", "S", "Cl", "Ar", "K", "Ca", "Sc", "Ti", "V", "Cr", "Mn", "Fe", "Co", 
		 "Ni", "Cu", "Zn", "Ga", "Ge", "As", "Se", "Br", "Kr", "Rb", "Sr", "Y", "Zr", "Nb", "Mo", "Tc", "Ru", "Rh", "Pd", "Ag", "Cd", "In", "Sn", "Sb", "Te", 
		 "I", "Xe", "Cs", "Ba", "La", "Ce", "Pr", "Nd", "Pm", "Sm", "Eu", "Gd", "Tb", "Dy", "Ho", "Er", "Tm", "Yb", "Lu", "Hf", "Ta", "W", "Re", "Os", "Ir", 
		 "Pt", "Au", "Hg", "Tl", "Pb", "Bi", "Po", "At", "Rn", "Fr", "Ra", "Ac", "Th", "Pa", "U", "Np", "Pu", "Am", "Cm", "Bk", "Cf", "Es", "Fm", "Md", "No", 
		 "Lr", "Rf", "Db", "Sg", "Bh", "Hs", "Mt", "Uun", "Uuu", "Uub"};

	public final static String[] terms = {"2S", "1S", "2S", "1S", "2P", "3P", "4S", "3P", "2P", "1S", "2S",  "1S", "2P", "3P", "4S", "3P", "2P", "1S", "2S", "1S", "2D", "3F",  "4F", "7S", "6S", "5D", "4F", "3F", "2S", "1S", "2P", "3P", "4S",  "3P", "2P", "1S", "2S", "1S", "2D", "3F", "6D", "7S", "6S", "5F",  "4F", "1S", "2S", "1S", "2P", "3P", "4S", "3P", "2P", "1S", "2S",  "1S", "2D", "1G", "4I", "5I", "6H", "7F", "8S", "9D", "6H", "5I",  "4I", "3H", "2F", "1S", "2D", "3F", "4F", "5D", "6S", "5D", "4F",  "3D", "2S", "1S", "2P", "3P", "4S", "3P", "2P", "1S", "2S", "1S",  "2D", "3F", "1S", "1S", "1S", "7F", "8S", "9D", "6H", "5I", "4I",  "3H", "2F", "1S", "2P", "3F", "1S", "1S", "1S", "1S", "1S"};

	public final static int[][][] groundStates = {
		{{1, 0, 1}}, {{1, 0, 2}}, {{1, 0, 2}, {2, 0, 1}}, {{1, 0, 2}, {2, 0, 2}}, {{1, 0, 2}, {2, 0, 2},
		{2, 1, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 3}}, {{1, 0, 2},
		{2, 0, 2}, {2, 1, 4}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 5}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}},
		{{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}},
		{{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		{3, 0, 2}, {3, 1, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 3}}, {{1, 0, 2},
		{2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 4}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 5}},
		{{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2},
		{3, 1, 6}, {4, 0, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {4, 0, 2}}, {{1, 0, 2},
		{2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 1}, {4, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		{3, 0, 2}, {3, 1, 6}, {3, 2, 2}, {4, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6},
		{3, 2, 3}, {4, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 5}, {4, 0, 1}},
		{{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 5}, {4, 0, 2}}, {{1, 0, 2}, {2, 0, 2},
		{2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 6}, {4, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2},
		{3, 1, 6}, {3, 2, 7}, {4, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 8},
		{4, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 1}}, {{1, 0, 2},
		{2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		{3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2},
		{3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6},
		{3, 2, 10}, {4, 0, 2}, {4, 1, 3}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		{4, 0, 2}, {4, 1, 4}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, 
		{4, 1, 5}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}},
		{{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {5, 0, 1}},
		{{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {5, 0, 2}},
		{{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 1},
		{5, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6},
		{4, 2, 2}, {5, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2},
		{4, 1, 6}, {4, 2, 4}, {5, 0, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		{4, 0, 2}, {4, 1, 6}, {4, 2, 5}, {5, 0, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6},
		{3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 5}, {5, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2},
		{3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 7}, {5, 0, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		{3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 8}, {5, 0, 1}}, {{1, 0, 2}, {2, 0, 2},
		{2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}}, {{1, 0, 2}, {2, 0, 2},
		{2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {5, 0, 1}}, {{1, 0, 2},
		{2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {5, 0, 2}},
		{{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10},
		{5, 0, 2}, {5, 1, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2},
		{4, 1, 6}, {4, 2, 10}, {5, 0, 2}, {5, 1, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6},
		{3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {5, 0, 2}, {5, 1, 3}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		{3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {5, 0, 2}, {5, 1, 4}}, {{1, 0, 2},
		{2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {5, 0, 2},
		{5, 1, 5}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6},
		{4, 2, 10}, {5, 0, 2}, {5, 1, 6}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		{4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {5, 0, 2}, {5, 1, 6}, {6, 0, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		{3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {5, 0, 2}, {5, 1, 6}, {6, 0, 2}},
		{{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10},
		{5, 0, 2}, {5, 1, 6}, {5, 2, 1}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6},
		{3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 2}, {5, 0, 2}, {5, 1, 6}, {6, 0, 2}}, {{1, 0, 2},
		{2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 3},
		{5, 0, 2}, {5, 1, 6}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		{4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 4}, {5, 0, 2}, {5, 1, 6}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2},
		{2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 5}, {5, 0, 2},
		{5, 1, 6}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2},
		{4, 1, 6}, {4, 2, 10}, {4, 3, 6}, {5, 0, 2}, {5, 1, 6}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		{3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 7}, {5, 0, 2}, {5, 1, 6},
		{6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6},
		{4, 2, 10}, {4, 3, 7}, {5, 0, 2}, {5, 1, 6}, {5, 2, 1}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		{3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 9}, {5, 0, 2}, {5, 1, 6},
		{6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6},
		{4, 2, 10}, {4, 3, 10}, {5, 0, 2}, {5, 1, 6}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2},
		{3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 11}, {5, 0, 2}, {5, 1, 6}, {6, 0, 2}},
		{{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10},
		{4, 3, 12}, {5, 0, 2}, {5, 1, 6}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6},
		{3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 13}, {5, 0, 2}, {5, 1, 6}, {6, 0, 2}}, {{1, 0, 2},
		{2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14},
		{5, 0, 2}, {5, 1, 6}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		{4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 1}, {6, 0, 2}}, {{1, 0, 2},
		{2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14},
		{5, 0, 2}, {5, 1, 6}, {5, 2, 2}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6},
		{3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 3}, {6, 0, 2}},
		 {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10},
		 {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 4}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2},
		 {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 5},
		 {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6},
		 {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 6}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		 {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6},
		 {5, 2, 7}, {6, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2},
		 {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 9}, {6, 0, 1}}, {{1, 0, 2}, {2, 0, 2},
		 {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2},
		 {5, 1, 6}, {5, 2, 10}, {6, 0, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		 {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {6, 0, 2}}, {{1, 0, 2},
		 {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14},
		 {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {6, 0, 2}, {6, 1, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2},
		 {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10},
		 {6, 0, 2}, {6, 1, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, 
		 {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {6, 0, 2}, {6, 1, 3}}, {{1, 0, 2},
		 {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14},
		 {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {6, 0, 2}, {6, 1, 4}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2},
		 {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10},
		 {6, 0, 2}, {6, 1, 5}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2},
		 {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {6, 0, 2}, {6, 1, 6}}, {{1, 0, 2},
		 {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14},
		 {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {6, 0, 2}, {6, 1, 6}, {7, 0, 1}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		 {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6},
		 {5, 2, 10}, {6, 0, 2}, {6, 1, 6}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6},
		 {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {6, 0, 2},
		 {6, 1, 6}, {6, 2, 1}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		 {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {6, 0, 2}, {6, 1, 6},
		 {6, 2, 2}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2},
		 {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 2}, {6, 0, 2}, {6, 1, 6},
		 {6, 2, 1}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2},
		 {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 3}, {6, 0, 2}, {6, 1, 6},
		 {6, 2, 1}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2},
		 {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 4}, {6, 0, 2}, {6, 1, 6},
		 {6, 2, 1}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2},
		 {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 6}, {6, 0, 2}, {6, 1, 6},
		 {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6},
		 {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 7}, {6, 0, 2}, {6, 1, 6}, {7, 0, 2}},
		 {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10},
		 {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 7}, {6, 0, 2}, {6, 1, 6}, {6, 2, 1}, {7, 0, 2}},
		 {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10},
		 {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 9}, {6, 0, 2}, {6, 1, 6}, {7, 0, 2}}, {{1, 0, 2},
		 {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14},
		 {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 10}, {6, 0, 2}, {6, 1, 6}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2},
		 {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2},
		 {5, 1, 6}, {5, 2, 10}, {5, 3, 11}, {6, 0, 2}, {6, 1, 6}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6},
		 {3, 0, 2}, {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6},
		 {5, 2, 10}, {5, 3, 12}, {6, 0, 2}, {6, 1, 6}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2},
		 {3, 1, 6}, {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10},
		 {5, 3, 13}, {6, 0, 2}, {6, 1, 6}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6},
		 {3, 2, 10}, {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 14},
		 {6, 0, 2}, {6, 1, 6}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		 {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 14}, {6, 0, 2},
		 {6, 1, 6}, {6, 2, 1}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		 {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 14}, {6, 0, 2},
		 {6, 1, 6}, {6, 2, 2}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		 {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 14}, {6, 0, 2},
		 {6, 1, 6}, {6, 2, 3}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		 {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 14}, {6, 0, 2},
		 {6, 1, 6}, {6, 2, 4}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		 {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 14}, {6, 0, 2},
		 {6, 1, 6}, {6, 2, 5}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		 {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 14}, {6, 0, 2},
		 {6, 1, 6}, {6, 2, 6}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		 {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 14}, {6, 0, 2},
		 {6, 1, 6}, {6, 2, 7}, {7, 0, 2}}, {{1, 0, 2}, {2, 0, 2}, {2, 1, 6}, {3, 0, 2}, {3, 1, 6}, {3, 2, 10},
		 {4, 0, 2}, {4, 1, 6}, {4, 2, 10}, {4, 3, 14}, {5, 0, 2}, {5, 1, 6}, {5, 2, 10}, {5, 3, 14}, {6, 0, 2},
		 {6, 1, 6}, {6, 2, 8}, {7, 0, 2}}
	};

}
