/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.border.*;
import java.io.*;
import java.util.*;

public class HFApplet extends JApplet implements ActionListener, ComponentListener, ChangeListener {
	HFTabs tabs;
	HFInput hfInput;
	HFIO hfIO;	
	String connectStatus;
	ElectronConfiguration lastConfiguration;
	int status = HFIOException.NO_RESULT;
	Object currentTab;

	//init sets up GUI
	public void init() {
		//set look and feel
		try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
	//		UIManager.setLookAndFeel("net.sourceforge.napkinlaf.NapkinLookAndFeel");
	//		UIManager.setLookAndFeel("javax.swing.plaf.metal.MetalLookAndFeel");
	//		UIManager.setLookAndFeel("com.sun.java.swing.plaf.motif.MotifLookAndFeel");
	//		UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
 
    		// Get the available Look and Feels.
//    		UIManager.LookAndFeelInfo [] lanf =
//     		UIManager.getInstalledLookAndFeels ();
    		// Print out the list of L&Fs
//    		for (int i=0; i < lanf.length; i++) {
//			   System.out.println (i+". L&F installed = " +lanf[i].getName ());
//			}
		} catch (Exception e) { }

	//	int screenRes = Toolkit.getDefaultToolkit().getScreenResolution();
	//	int fontSize = (int)Math.round(12.0 * screenRes / 72.0);
	//	Font font = new Font("Arial", Font.PLAIN, fontSize);
	//	setUIFont (new javax.swing.plaf.FontUIResource("Serif",Font.PLAIN,12));
		UIManager.put("TableHeader.font", new Font("Serif",Font.PLAIN,11));


		//get background color specified by caller, if exists
		String backgroundColorString = getParameter("backgroundColor");
		try {
			if (backgroundColorString != null) {
				getContentPane().setBackground(Color.decode(backgroundColorString));
			}
		} catch (NumberFormatException e) {	}

		//set layout manager
		getContentPane().setLayout(new BoxLayout(getContentPane(), BoxLayout.PAGE_AXIS));
		getRootPane().setBorder(BorderFactory.createEmptyBorder());

		//create tabbed pane
		tabs = new HFTabs();
		getContentPane().add(tabs);
		currentTab = tabs.getSelectedComponent();

		//create input pane
		JPanel panel = new JPanel();
		panel.setBackground(null);
		getContentPane().add(panel);

		hfInput = new HFInput();
		panel.add(hfInput);

		//add listeners
		panel.addComponentListener(this);
		hfInput.runButton.addActionListener(this);
		hfInput.configDisplay.addActionListener(this);
		tabs.addChangeListener(this);
		tabs.ptControl.addActionListener(this);
		tabs.outputPanel.slaterButton.addActionListener(this);
		tabs.outputPanel.rkButton.addActionListener(this);
		tabs.outputPanel.soButton.addActionListener(this);
    }
	
	public void disconnect() {
		if (hfIO != null) {
			try {
				hfIO.disconnect();
			} catch (IOException e) {
				showStatus(e.toString());
			}
		}
	}

	//event handlers
	public void componentHidden(ComponentEvent e) {}
	public void componentMoved(ComponentEvent e) {}
	public void componentResized(ComponentEvent e) {
		tabs.ptControl.scaleTextSize();	
	}
	public void componentShown(ComponentEvent e) {}
	
	public void stateChanged(ChangeEvent e) {
		Component source = (Component)e.getSource();
		//we need to destroy the plot when its tab is not shown, because it tends to try to draw itself anyway.
		if (source == tabs) {
			//if we're moving to the plot tab, draw the plot, if appropriate
			if (tabs.getSelectedComponent().equals(tabs.wfPlot)) {
				if (status == HFIOException.SUCCESS
					&& (lastConfiguration != null && hfInput.getConfiguration().equals(lastConfiguration))) {
					int[] toShow = stringLocations(hfIO.nlArray, hfInput.configDisplay.getSubshellsToShow());
					tabs.wfPlot.plotData(hfIO.wfArray, hfIO.expectationArray[0], hfIO.nlArray, toShow);
				}
			} else { //if we're moving away from the plot tab, destroy the plot tab, if it still exists
				if (currentTab.equals(tabs.wfPlot)) {
					int index = tabs.indexOfComponent(tabs.wfPlot);
					if (index >= 0) {
						tabs.remove(tabs.wfPlot);
						tabs.wfPlot = new WFPlot();
						tabs.insertTab("Plot",null,tabs.wfPlot,null,index);
					}
				}				
			}
			currentTab=tabs.getSelectedComponent();
		}
	}

	public void actionPerformed(ActionEvent event) {
		Component source = (Component)event.getSource();
//		System.out.println(source);
		try	{
			if (source == hfInput.runButton) {
				//initialize IO
				if (status == HFIOException.SUCCESS) {
					hfIO.endCalculation();
				} else {
					if (status == HFIOException.NO_RESULT) hfIO = new HFIO();
					showStatus("Connecting to: " + getCodeBase().getHost());
					connectStatus = hfIO.connect(getCodeBase().getHost());
					showStatus(connectStatus);
				}
				
				try {
					//send and recieve data
					showStatus("communicating with server...");
					lastConfiguration = (ElectronConfiguration)hfInput.getConfiguration().clone();
					hfIO.requestData(hfInput.elemAbbr, hfInput.atomicNumber,
								hfInput.getConfiguration(), hfInput.reuseControl.isSelected() && hfIO.ouf != null,
								hfInput.strongControl.isSelected(), ((Double)hfInput.accControl.getValue()).doubleValue());
					showStatus(connectStatus);

					//update displays
					updateDisplays(status = HFIOException.SUCCESS);
					hfInput.reuseControl.setEnabled(true);
					tabs.outputPanel.setButtonsEnabled(true);
					if (tabs.getSelectedComponent() == tabs.frontPanel) tabs.setSelectedComponent(tabs.wfPlot);

				} catch (HFIOException hfE) {
					updateDisplays(status = hfE.getStatus());
					hfInput.reuseControl.setEnabled(hfIO.ouf != null);
					tabs.outputPanel.setButtonsEnabled(false);
					JOptionPane.showMessageDialog(this, hfE.getMessage());
				}
			}

			if (source == tabs.ptControl) {
				//update values to reflect new element
				hfInput.setAtomicNumber(Integer.valueOf(event.getActionCommand()).intValue());
			}

			if (source == hfInput.configDisplay) {
				hfInput.configDisplay.scaleTextSize();
				updateDisplays(status);
			}
			
			if (source == tabs.outputPanel.slaterButton || 
				source == tabs.outputPanel.rkButton ||
				source == tabs.outputPanel.soButton) {
				if (status == HFIOException.SUCCESS) {
					try {
						if (source == tabs.outputPanel.slaterButton) {
							hfIO.getSlaterIntegral(tabs.outputPanel.getSlaterInput(lastConfiguration));
							tabs.outputPanel.updateSlaterOutput(hfIO.slaterValues);
						}
						if (source == tabs.outputPanel.rkButton) {
							hfIO.getRKIntegral(tabs.outputPanel.getRKInput(lastConfiguration));
							tabs.outputPanel.updateRKOutput(hfIO.rkValue);
						}
						if (source == tabs.outputPanel.soButton) {
							hfIO.getSOParameter(tabs.outputPanel.getSOInput(lastConfiguration));
							tabs.outputPanel.updateSOOutput(hfIO.soValues);
						}
					} catch (ShellException e) {
						JOptionPane.showMessageDialog(this,"Orbital does not exist.");
					} catch (IOException e) {
						JOptionPane.showMessageDialog(this,"Could not evaluate the integral.");
					}
				} else {
					JOptionPane.showMessageDialog(this,"The calculation must be run before integrals can be computed.");
				}
			}
		} catch (IOException e) {
			showStatus(e.toString());
			disconnect();
			status = HFIOException.NO_RESULT;
		}
	}

	void updateDisplays(int status) {
		if (status == HFIOException.NO_RESULT 
			|| (lastConfiguration != null && !hfInput.getConfiguration().equals(lastConfiguration))) {
			//clear all displays
			tabs.wfPlot.clearData();
			tabs.expectations.clearData();
			tabs.initialEstimates.clearData();
			tabs.setEnergyOutput();
			tabs.iterations.setText("");
			tabs.wfPlot.repaint();
		} else if (status == HFIOException.SUCCESS) {
			//display all data for selected subshells
			int[] toShow = stringLocations(hfIO.nlArray, hfInput.configDisplay.getSubshellsToShow());
			tabs.wfPlot.plotData(hfIO.wfArray, hfIO.expectationArray[0], hfIO.nlArray, toShow);
			tabs.updateTable(tabs.expectations, hfIO.nlArray, hfIO.expectationArray, toShow);
			tabs.updateTable(tabs.initialEstimates, hfIO.nlArray, hfIO.estimatesArray, toShow);
			tabs.setEnergyOutput(hfIO.energies);
			tabs.iterations.setText(hfIO.iterationsText.getText());
		} else if (status == HFIOException.NONCONVERGENCE) {
			//just show initial estimates and iterations
			int[] toShow = stringLocations(hfIO.nlArray, hfInput.configDisplay.getSubshellsToShow());
			tabs.wfPlot.clearData();
			tabs.expectations.clearData();
			tabs.updateTable(tabs.initialEstimates, hfIO.nlArray, hfIO.estimatesArray, toShow);
			tabs.setEnergyOutput();
			tabs.iterations.setText(hfIO.iterationsText.getText());
		}
		
		//clear output panel
		tabs.outputPanel.updateSlaterOutput();
		tabs.outputPanel.updateRKOutput();
		tabs.outputPanel.updateSOOutput();
	}

	//stringLocations: finds indicies of the elements of an array
	//of strings as they appear in another array  
	int[] stringLocations(String[] array, String[] subarray) {
		Vector<Integer> locations = new Vector<Integer>();
		java.util.List list = Arrays.asList(array);
		int j;
		for (int i=0; i<subarray.length; i++) {
			if ((j = list.indexOf(subarray[i])) >= 0) locations.add(new Integer(j));
		}
		int[] locsArray = new int[locations.size()]; 
		for (int i=0; i<locations.size(); i++) locsArray[i] = locations.elementAt(i).intValue();
		return locsArray;
	}
	
	public static void setUIFont (javax.swing.plaf.FontUIResource f){
		//
		// sets the default font for all Swing components.
		// ex. 
		//  setUIFont (new javax.swing.plaf.FontUIResource("Serif",Font.ITALIC,12));
		//
		//
		//		For a particuliar component
		//UIManager.put("Label.font",new Font("Serif",Font.ITALIC,12));

		java.util.Enumeration keys = UIManager.getDefaults().keys();
		while (keys.hasMoreElements()) {
		  Object key = keys.nextElement();
		  Object value = UIManager.get (key);
		  if (value instanceof javax.swing.plaf.FontUIResource) {
		//	UIManager.put (key, f);
			System.out.println(key);
		//	System.out.println(value);
		  }
		}
	}   

}
