/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

public class HFIOException extends Exception {
	String message;
	int status;
	static int SUCCESS = 0, NO_RESULT = 1, NONCONVERGENCE = 2;

	public HFIOException() {
		super();
	}

	public HFIOException(String s) {
		super();
		
		if (s.equals("unsupported configuration")) {
			status = NO_RESULT;
			message = "The configuration must be one of the following:\n"
			+	"1) an open p- , d- or f-shell\n"
			+ 	"2) a single electron or hole, any l\n"
			+	"3) an s-electron and a single electron, any l\n"
			+	"4) an s-electron and an open p- , d- or f-shell\n"
			+	"5) an open p-shell and a single electron, any l\n"
			+	"6) a single electron in f- and a single electron in d-shells";
		
		} else if (s.equals("ambiguous term")) {
			status = NO_RESULT;
			message = "Calculation failed: ambiguous term.";
		
		} else if (s.equals("failed")) {
			status = NONCONVERGENCE;
			message = "The calculation failed.\n"
					+ "For more info, select Iterations tab.";
		} else if (s.equals("no electrons")) {
			status = NO_RESULT;
			message = "There must be at least one electron.";
		}
	}

	public HFIOException(String s1, String s2) {
		super();
		if (s1.equals("did not converge")) {
			status = NONCONVERGENCE;
			message = "The calculation failed to converge in " + s2 + " iterations.\n"
					+ "For more info, select Iterations tab.";
		}
		if (s1.equals("charge zero")) {
			status = NO_RESULT;
			message = "Calculation failed: effective nuclear charge zero for " + s2 + " orbital.";
		}
	}

	public String getMessage() {
		return message;
	}

	public int getStatus() {
		return status;
	}
}
