/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.event.*;
import javax.swing.border.*;
import javax.swing.text.*;
import java.io.*;
import java.util.Arrays;
import java.util.Vector;

public class HFInput extends JPanel implements ActionListener, ChangeListener {
	JToolBar toolBar;
	JButton runButton, groundState, plusButton, minusButton;
	Icon blackRun, redRun;
	JToggleButton expandCore, reuseControl, strongControl;
	ConfigurationDisplay configDisplay;
	JLabel abbrLabel;
	ElectronConfiguration elecConfig, lastConfig = null;
	TitledBorder configLabel;
	String elemAbbr, elemName;
	JSpinner Lspinner, multiSpinner, accControl;
	OrbitalSelector orbitalSelector;
	Insets buttonMargin = new Insets(0,0,0,0);
	int atomicNumber = 3; //default is Li

	public HFInput() {
		super();
		setLayout(new BoxLayout(this, BoxLayout.PAGE_AXIS));
//		setLayout(new GridLayout(0,1));
		setBorder(BorderFactory.createEtchedBorder());
		int widthAdj = 0; // adjustment for size of spinners
		if (UIManager.getSystemLookAndFeelClassName()=="com.sun.java.swing.plaf.gtk.GTKLookAndFeel") {
			widthAdj = -5;
		}

		// configuration display
		configDisplay = new ConfigurationDisplay();
		configLabel = BorderFactory.createTitledBorder("");
		configDisplay.setBorder(configLabel);
		add(configDisplay);

		// tool bar
		toolBar = new JToolBar();
		toolBar.setFloatable(false);
		//toolBar.setAlignmentX(Component.LEFT_ALIGNMENT);
		add(toolBar);
		
		// expand/contract configuration button
		expandCore = new JToggleButton(AppletImage.createAppletImageIcon(HFApplet.class,"images/expand.gif", "expand"));
		expandCore.setSelectedIcon(AppletImage.createAppletImageIcon(HFApplet.class,"images/contract.gif", "contract"));
		expandCore.setMargin(buttonMargin);
		expandCore.setToolTipText("expand/contract noble gas configuration");
		expandCore.addActionListener(this);
		expandCore.setEnabled(false);
		toolBar.add(expandCore);

		// ground state button
		groundState = new JButton(AppletImage.createAppletImageIcon(HFApplet.class,"images/ground.gif", "Ground state"));
		groundState.addActionListener(this);
		groundState.setToolTipText("reset to ground state");
		groundState.setMargin(buttonMargin);
		groundState.setEnabled(false);
		toolBar.add(groundState);

		toolBar.addSeparator();
		
		// add/remove electron control
		orbitalSelector = new OrbitalSelector();
		setSizes(orbitalSelector.nSpinner,addToDimension(orbitalSelector.nSpinner.getPreferredSize(),widthAdj,0));
		toolBar.add(orbitalSelector);
		plusButton = new JButton(AppletImage.createAppletImageIcon(HFApplet.class,"images/Plus.gif", "plus"));
		plusButton.addActionListener(this);
		plusButton.setToolTipText("add an electron");
		plusButton.setMargin(buttonMargin);
		toolBar.add(plusButton);
		minusButton = new JButton(AppletImage.createAppletImageIcon(HFApplet.class,"images/Minus.gif", "minus"));
		minusButton.addActionListener(this);
		minusButton.setToolTipText("remove an electron");
		minusButton.setMargin(buttonMargin);
		toolBar.add(minusButton);

		toolBar.addSeparator();

		// multiplicity control
		JLabel label = new JLabel(" 2S+1 = ");
		label.setToolTipText("set multiplicity");
		setSizes(label,label.getPreferredSize());
		toolBar.add(label);
		multiSpinner = new JSpinner(new SpinnerNumberModel(0, 0, 9, 1));
		setSizes(multiSpinner, addToDimension(multiSpinner.getPreferredSize(),widthAdj,0));
		multiSpinner.addChangeListener(this);
		multiSpinner.setToolTipText("set multiplicity");
		toolBar.add(multiSpinner);

		// L control
		label = new JLabel(" L = ");
		label.setToolTipText("set L value");
		toolBar.add(label);
		Lspinner = new JSpinner(new SpinnerNumberModel(0, 0, 9, 1));
		setSizes(Lspinner, addToDimension(Lspinner.getPreferredSize(),widthAdj,0));
		Lspinner.addChangeListener(this);
		toolBar.add(Lspinner);
		
		toolBar.addSeparator();

		// acc control
		label = new JLabel(" ACC = ");
		label.setToolTipText("set acceleration factor");
		toolBar.add(label);
		accControl = new JSpinner(new SpinnerNumberModel(0.0, 0.0, 1.0, 0.1));
		accControl.setEditor(new JSpinner.NumberEditor(accControl, "0.0"));
		setSizes(accControl, addToDimension(accControl.getPreferredSize(),4*widthAdj,0));
		toolBar.add(accControl);

		// strong control
		strongControl = new JToggleButton(AppletImage.createAppletImageIcon(HFApplet.class,"images/strongicon.gif", "strong"));
		strongControl.addActionListener(this);
		strongControl.setToolTipText("strong orthogonality");
		strongControl.setMargin(buttonMargin);
		toolBar.add(strongControl);

		// reuse control
		reuseControl = new JToggleButton(AppletImage.createAppletImageIcon(HFApplet.class,"images/reuseicon.gif", "reuse"));
		reuseControl.addActionListener(this);
		reuseControl.setToolTipText("reuse wavefunctions");
		reuseControl.setMargin(buttonMargin);
		reuseControl.setEnabled(false);
		toolBar.add(reuseControl);

		// run button
		blackRun = AppletImage.createAppletImageIcon(HFApplet.class, "images/runIcon.gif", "run");
		redRun = AppletImage.createAppletImageIcon(HFApplet.class, "images/redrunIcon.gif", "run");
		runButton = new JButton(redRun);
		runButton.setMnemonic(KeyEvent.VK_R);
		runButton.setToolTipText("run the calculation");
		runButton.setMargin(buttonMargin);
		runButton.addActionListener(this);
		toolBar.add(runButton);

		elecConfig = new ElectronConfiguration();
		setAtomicNumber(atomicNumber);
	}

	Dimension addToDimension(Dimension d, int dx, int dy) {
		return new Dimension(d.width+dx,d.height+dy);
	}
	
	void setSizes(JComponent c, Dimension d) {
		c.setMaximumSize(d);
		c.setMinimumSize(d);
		c.setPreferredSize(d);
	}

	public ElectronConfiguration getConfiguration() {
		return elecConfig;
	}

	public void setAtomicNumber(int atomicNumber) {
		this.atomicNumber = atomicNumber;
		elecConfig.setToGroundState(atomicNumber);
		elemName = ElementsData.getName(atomicNumber);
		elemAbbr = ElementsData.getAbbreviation(atomicNumber);
		configLabel.setTitle(elemName + " Z = " + String.valueOf(atomicNumber));
		configDisplay.setConfiguration(elecConfig);
		configDisplay.selectOutsideCore();
		Lspinner.setValue(new Integer(elecConfig.getL()));
		multiSpinner.setValue(new Integer(elecConfig.getMultiplicity()));
		updateButtonAbility();
	}

	public void updateButtonAbility() {
		expandCore.setEnabled(configDisplay.getNobleNumber() > 0);
		ElectronConfiguration gs = new ElectronConfiguration(atomicNumber);
		groundState.setEnabled(!elecConfig.equals(gs));
//		System.out.println(lastConfig);
		runButton.setIcon(lastConfig != null && elecConfig.equals(lastConfig) ? blackRun : redRun);
	}

	//event handler
	public void actionPerformed(ActionEvent event) {
		Object source = event.getSource();
		
		if (source == plusButton) {
			//add electron, if possible
			String subshell = orbitalSelector.getOrbital();
			ElectronSubshell toOrbital = new ElectronSubshell(subshell);
			try {
				elecConfig.addElectron(toOrbital);
			} catch (ShellException e) {
				JOptionPane.showMessageDialog(this, "The " + subshell + " subshell is already full.");
			}
			configDisplay.setConfiguration(elecConfig);
			configDisplay.selectOpenShells();
		}

		if (source == minusButton) {
			//remove electron, if possible
			String subshell = orbitalSelector.getOrbital();
			ElectronSubshell fromOrbital = new ElectronSubshell(subshell);
			try {
				elecConfig.removeElectron(fromOrbital);
			} catch (ShellException e) {
				JOptionPane.showMessageDialog(this, "The " + subshell + " subshell is already empty.");
			}
			configDisplay.setConfiguration(elecConfig);
			configDisplay.selectOpenShells();
		}
		
		if (source == expandCore) {
			configDisplay.setContractCore(!expandCore.isSelected());
			configDisplay.setConfiguration(elecConfig);
		}

		if (source == groundState) {
			//reset configuration to ground state
			setAtomicNumber(atomicNumber);
		}

		if (source == runButton) {
			lastConfig = (ElectronConfiguration)elecConfig.clone();
		}

		updateButtonAbility();
	}

	public void stateChanged(ChangeEvent event) {
		Object source = event.getSource();

		if (source == multiSpinner) {
			elecConfig.setMultiplicity(multiSpinner.getValue().toString());
			configDisplay.setConfiguration(elecConfig);
			updateButtonAbility();
		}

		if (source == Lspinner) {
			elecConfig.setL(Lspinner.getValue().toString());
			configDisplay.setConfiguration(elecConfig);
			updateButtonAbility();
		}
	}
}
