/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import javax.swing.*;
import java.util.Arrays;
import java.awt.*;
import javax.swing.event.*;
import java.awt.event.*;
import java.text.*;

public class HFOutputPanel extends JPanel implements ChangeListener, ActionListener{
	OrbitalSelector slaterOrbitalSelector1, slaterOrbitalSelector2;
	JSpinner slaterSpinner, slaterKSpinner;
	JLabel slaterOutput;
	JToolBar slaterInput;
	JPanel slaterPanel;
	JButton slaterButton;

	OrbitalSelector rkOrbitalSelector;
	JSpinner rkKSpinner;
	JLabel rkOutput;
	JPanel rkPanel;
	JToolBar rkInput;
	JButton rkButton;

	OrbitalSelector soOrbitalSelector;
	JLabel soOutput;
	JToolBar soInput;
	JPanel soPanel;
	JButton soButton;

	public HFOutputPanel() {
		super();
		setLayout(new BoxLayout(this, BoxLayout.PAGE_AXIS));
		add(Box.createVerticalGlue());

		/**** R^k INTEGRALS ****/
		rkPanel = new JPanel();
		rkPanel.setLayout(new BoxLayout(rkPanel, BoxLayout.PAGE_AXIS));
		rkPanel.setPreferredSize(new Dimension(1000,90));
		rkPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
		rkInput = new JToolBar();
		rkInput.setFloatable(false);
		rkPanel.setBorder(BorderFactory.createTitledBorder("Powers of r averages"));
		add(rkPanel);
		//orbital selector
		rkOrbitalSelector = new OrbitalSelector();
		rkOrbitalSelector.addActionListener(this);
		rkInput.add(rkOrbitalSelector);
		//k spinner
		rkInput.add(new JLabel(" k = "));
		rkInput.add(rkKSpinner = createKSpinner());
		//execute button
		rkInput.add(Box.createRigidArea(new Dimension(5,0)));
		rkInput.add(rkButton = createExecuteButton());
		rkInput.add(Box.createRigidArea(new Dimension(5,0)));

		//output
		rkOutput = new JLabel();
		
		rkInput.setAlignmentX(Component.LEFT_ALIGNMENT);
		rkOutput.setAlignmentX(Component.LEFT_ALIGNMENT);		
		rkPanel.add(rkInput);
		rkPanel.add(rkOutput);		
		add(Box.createVerticalGlue());

		/**** SLATER INTEGRALS ****/
		slaterPanel = new JPanel();
		slaterPanel.setLayout(new BoxLayout(slaterPanel, BoxLayout.PAGE_AXIS));
		slaterPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
		slaterPanel.setPreferredSize(new Dimension(1000,90));
		slaterInput = new JToolBar();
		slaterInput.setFloatable(false);
		slaterPanel.setBorder(BorderFactory.createTitledBorder("Slater integrals"));
		add(slaterPanel);
		//integral type spinner
		String[] slaterValues = {"F", "G", "N", "M", "V"};
		slaterSpinner = new JSpinner(new SpinnerListModel(Arrays.asList(slaterValues)));
		setSizes(slaterSpinner,slaterSpinner.getPreferredSize());
		slaterSpinner.addChangeListener(this);
		slaterInput.add(slaterSpinner);
		//Slater k spinner
		slaterInput.add(new JLabel(" k= "));
		slaterInput.add(slaterKSpinner = createKSpinner());
		//orbital selectors		
		slaterInput.add(new JLabel(" ( "));
		slaterOrbitalSelector1 = new OrbitalSelector();
		slaterOrbitalSelector1.addActionListener(this);
		slaterInput.add(slaterOrbitalSelector1);
		slaterInput.add(new JLabel(" , "));
		slaterOrbitalSelector2 = new OrbitalSelector();
		slaterOrbitalSelector2.addActionListener(this);
		slaterInput.add(slaterOrbitalSelector2);
		slaterInput.add(new JLabel(" ) "));
		//execute button
		slaterInput.add(Box.createRigidArea(new Dimension(5,0)));
		slaterInput.add(slaterButton = createExecuteButton());
		slaterInput.add(Box.createRigidArea(new Dimension(5,0)));
		//output
		slaterOutput = new JLabel();

		slaterInput.setAlignmentX(Component.LEFT_ALIGNMENT);
		slaterOutput.setAlignmentX(Component.LEFT_ALIGNMENT);		
		slaterPanel.add(slaterInput);
		slaterPanel.add(slaterOutput);
		add(Box.createVerticalGlue());

		/**** Spin-Orbit parameters ****/
		soPanel = new JPanel();
		soPanel.setLayout(new BoxLayout(soPanel, BoxLayout.PAGE_AXIS));
		soPanel.setPreferredSize(new Dimension(1000,90));
		soPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
		soInput = new JToolBar();
		soInput.setFloatable(false);
		soPanel.setBorder(BorderFactory.createTitledBorder("Spin-orbit parameters"));
		add(soPanel);
		//orbital selector
		soOrbitalSelector = new OrbitalSelector();
		soOrbitalSelector.addActionListener(this);
		soInput.add(soOrbitalSelector);
		//execute button
		soInput.add(Box.createRigidArea(new Dimension(5,0)));
		soInput.add(soButton = createExecuteButton());
		soInput.add(Box.createRigidArea(new Dimension(5,0)));
		//output
		soOutput = new JLabel();

		soInput.setAlignmentX(Component.LEFT_ALIGNMENT);
		soOutput.setAlignmentX(Component.LEFT_ALIGNMENT);				
		soPanel.add(soInput);
		soPanel.add(soOutput);
		add(Box.createVerticalGlue());

		//initialize
		updateRKOutput();
		updateSlaterOutput();
		updateSOOutput();
	}

	public JButton createExecuteButton() {
		JButton button = new JButton(AppletImage.createAppletImageIcon(HFApplet.class,"images/runIcon.gif", "run"));
		button.setToolTipText("evaluate");
		button.setMargin(new Insets(2,2,2,2));
		button.setEnabled(false);
		return button;
	}

	public JSpinner createKSpinner() {
		JSpinner spinner = new JSpinner(new SpinnerNumberModel(0, 0, 9, 1));
		setSizes(spinner,spinner.getPreferredSize());
		spinner.addChangeListener(this);
		return spinner;
	}

	void setSizes(JComponent c, Dimension d) {
		c.setMaximumSize(d);
		c.setMinimumSize(d);
		c.setPreferredSize(d);
	}	

	public void setButtonsEnabled(boolean b) {
		slaterButton.setEnabled(b);
		rkButton.setEnabled(b);
		soButton.setEnabled(b);
	}

	public void updateRKOutput() {
		updateRKOutput("&nbsp;??&nbsp;"); 
	}

	public void updateRKOutput(double value) {
		updateRKOutput(String.valueOf(value)); 
	}

	public void updateRKOutput(String value) {
		rkOutput.setText("<html>&nbsp;&lt;&nbsp;" + rkOrbitalSelector.getOrbital() 
						+ " | r<sup>" + rkKSpinner.getValue() + "</sup> | "
						+ rkOrbitalSelector.getOrbital() + " &gt; = " + value + " a.u.</html>");
	}

	public String getRKInput(ElectronConfiguration config) throws ShellException {
		String nl = rkOrbitalSelector.getOrbital();
		boolean closed = config.getSubshell(nl).isFull();
		return " " + (closed ? "" : " ") + nl + (closed ? " " : "") + "  " + rkKSpinner.getValue();
	}

	public void updateSlaterOutput() {
		updateSlaterOutput("&nbsp;??&nbsp;","&nbsp;??&nbsp;"); 
	}

	public void updateSlaterOutput(double[] slaterValues) {
//	    DecimalFormat formatter = new DecimalFormat("0.###E0");
//		updateSlaterOutput((formatter.format(slaterValues[0])).toString(), 
//		(formatter.format(slaterValues[1])).toString());
		updateSlaterOutput(String.valueOf(slaterValues[0]), String.valueOf(slaterValues[1])); 
	}

	public void updateSlaterOutput(String auValue, String cmValue) {
		slaterOutput.setText("<html>&nbsp;" + slaterSpinner.getValue() 
								+ "<sup>" + slaterKSpinner.getValue() + "</sup>"
								+ "(" + slaterOrbitalSelector1.getOrbital() + ","
								+ slaterOrbitalSelector2.getOrbital() + ")"
								+ " = " + auValue + " a.u., " + cmValue + " cm<sup>-1</sup></html>");
	}

	public String getSlaterInput(ElectronConfiguration config) throws ShellException {
		String nl1 = slaterOrbitalSelector1.getOrbital();
		String nl2 = slaterOrbitalSelector2.getOrbital();
		boolean closed1 = config.getSubshell(nl1).isFull();
		boolean closed2 = config.getSubshell(nl2).isFull();
		return "" + slaterSpinner.getValue() + " " + slaterKSpinner.getValue() + 
				"(" + (closed1 ? "" : " ") + nl1 + (closed1 ? " " : "") +  ","
				    + (closed2 ? "" : " ") + nl2 + (closed2 ? " " : "") + ")";
	}

	public void updateSOOutput() {
		updateSOOutput("&nbsp;??&nbsp;","&nbsp;??&nbsp;"); 
	}

	public void updateSOOutput(double[] values) {
		updateSOOutput(String.valueOf(values[0]), String.valueOf(values[1])); 
	}

	public void updateSOOutput(String value1, String value2) {
		soOutput.setText("<html>&nbsp;" + soOrbitalSelector.getOrbital() 
						+ " spin-orbit parameter = " + value1 + " a.u., "  + value2 
						+ " cm<sup>-1</sup></html>");
	}

	public String getSOInput(ElectronConfiguration config) throws ShellException {
		String nl = "" + soOrbitalSelector.getOrbital();
		boolean closed = config.getSubshell(nl).isFull();
		return " " + (closed ? "" : " ") + nl + (closed ? " " : "");
	}

	public void stateChanged(ChangeEvent event) {
		Component source = ((Component)event.getSource()).getParent();

		if (source == slaterInput) updateSlaterOutput();
		if (source == rkInput) updateRKOutput();
		if (source == soInput) updateSOOutput();
	}

	public void actionPerformed(ActionEvent event) {
		Component source = ((Component)event.getSource()).getParent();

		if (source == slaterInput) updateSlaterOutput();
		if (source == rkInput) updateRKOutput();
		if (source == soInput) updateSOOutput();
	}
}
