/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import java.io.*;
import javax.swing.*;
import javax.swing.table.*;
import java.text.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.event.*;
import java.util.Arrays;
import java.net.URL;

public class HFTabs extends JTabbedPane {
	JTextArea iterations, energyOutput;
	DataTableModel expectations, initialEstimates;
	JTable expectationTable, estimatesTable;
	WFPlot wfPlot;
	PeriodicTableControl ptControl;
	HFOutputPanel outputPanel;
	JScrollPane iterationsPane;
	JPanel frontPanel;

	public HFTabs() {
		super();
		
		/***** FRONT PANEL *****/
		frontPanel = new JPanel();
		frontPanel.setLayout(new BoxLayout(frontPanel, BoxLayout.PAGE_AXIS));
		frontPanel.add(Box.createVerticalGlue());
		ptControl = new PeriodicTableControl();
		frontPanel.add(ptControl);
		frontPanel.add(Box.createVerticalGlue());
		addTab("Elements", frontPanel);

		/***** INITIAL ESTIMATES TAB *****/
		initialEstimates = new DataTableModel();
		initialEstimates.addColumn("nl");
		initialEstimates.addColumn("screening parameter");
		initialEstimates.addColumn("acceleration factor");
		initialEstimates.addColumn("wavefunction");
		estimatesTable = new JTable(initialEstimates);
		estimatesTable.setDefaultRenderer(Double.class, new DoubleRenderer(1));
		estimatesTable.setDefaultRenderer(String.class, new StringRenderer());
		estimatesTable.getTableHeader().setDefaultRenderer(new HeaderRenderer(estimatesTable.getTableHeader().getDefaultRenderer()));
		estimatesTable.getColumn("wavefunction").setCellRenderer(new FunctionRenderer());
	//	estimatesTable.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
		estimatesTable.getColumn("nl").setPreferredWidth(25);
		estimatesTable.getColumn("screening parameter").setPreferredWidth(100);
		estimatesTable.getColumn("acceleration factor").setPreferredWidth(100);
		estimatesTable.getColumn("wavefunction").setPreferredWidth(100);
		addTab("Estimates", new JScrollPane(estimatesTable));

		/***** ITERATIONS TAB *****/
		iterations = new JTextArea(20,20);
		iterations.setEditable(false);
		iterationsPane = new JScrollPane(iterations);
		iterationsPane.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));
		addTab("Iterations", iterationsPane);

		/***** WAVEFUNCTION PLOT TAB *****/
		wfPlot = new WFPlot();
		addTab("Plot", wfPlot);

		/***** AVERAGE VALUES TAB *****/
		JPanel averagePanel = new JPanel();
		averagePanel.setLayout(new BoxLayout(averagePanel, BoxLayout.PAGE_AXIS));
		//expectation table
		expectations = new DataTableModel();
		expectations.addColumn("<html>nl</html>");
		expectations.addColumn("<html>r&nbsp;</html>");
		expectations.addColumn("<html>r<sup>-1</sup>&nbsp;</html>");
		expectations.addColumn("<html>r<sup>-3</sup>&nbsp;</html>");
		expectations.addColumn("<html>r<sup>2</sup>&nbsp;</html>");
		expectations.addColumn("<html>E&nbsp;</html>");
		expectations.addColumn("<html>I&nbsp;</html>");
		expectations.addColumn("<html>KE&nbsp;</html>");
		expectationTable = new JTable(expectations);
		expectationTable.setDefaultRenderer(Double.class, new DoubleRenderer(2));
		expectationTable.setDefaultRenderer(String.class, new StringRenderer());
		expectationTable.getTableHeader().setDefaultRenderer(new HeaderRenderer(expectationTable.getTableHeader().getDefaultRenderer()));
		JScrollPane pane = new JScrollPane(expectationTable);
		pane.setAlignmentX(Component.CENTER_ALIGNMENT);
		averagePanel.add(pane);
		//energy data
		energyOutput = new JTextArea(6,100);
		setEnergyOutput();
		energyOutput.setMaximumSize(energyOutput.getPreferredSize());
		energyOutput.setAlignmentX(Component.CENTER_ALIGNMENT);
		averagePanel.add(energyOutput);
		JLabel label = new JLabel("<html>All values in atomic units (energy: 27.2 eV, length: a<sub>0</sub>)</html>", SwingConstants.LEFT);
		label.setAlignmentX(Component.CENTER_ALIGNMENT);
		averagePanel.add(label);
		addTab("Averages", averagePanel);

		/***** OTHER OUTPUT TAB *****/
		outputPanel = new HFOutputPanel();
		addTab("Other", outputPanel);

		/***** HELP ******/
        try {
        	URL helpURL = HFApplet.class.getResource("/helpFile.html");
			if (helpURL != null) {
					JEditorPane helpPane = new JEditorPane();
					helpPane.setEditable(false);
					helpPane.setPage(helpURL);
					JScrollPane scrollPane = new JScrollPane(helpPane);
					addTab("Help", scrollPane);
			}
		} catch (IOException e) {}
	}

	public void updateTable(DataTableModel tableModel, String[] nlArray, double[][] dataArray, int[] toShow) {
		tableModel.clearData();
		for (int i=0; i<toShow.length; i++) {
			tableModel.addRow();
			tableModel.setValueAt(nlArray[toShow[i]],i,0);
			for (int j=0; j<dataArray.length; j++) {
				tableModel.setValueAt(dataArray[j][toShow[i]],i,j+1);
			}
		}
	}

	public void setEnergyOutput() {
		setEnergyOutput("","","","");
	}

	public void setEnergyOutput(double[] e) {
		setEnergyOutput(String.valueOf(e[1]), String.valueOf(e[2]), String.valueOf(e[0]), String.valueOf(e[3]));
	}

	public void setEnergyOutput(String ke, String pe, String e, String r) {
		energyOutput.setText(null);
		energyOutput.append("Total energy\n");
		energyOutput.append("     Kinetic energy (K.E) = " + ke + "\n");
		energyOutput.append("     Potential energy (P.E) = " + pe + "\n");
		energyOutput.append("     Energy = K.E. + P.E. = " + e + "\n");
		energyOutput.append("Virial theorem\n");
		energyOutput.append("     Ratio = P.E./K.E. = " + r);
	}

	static class DoubleRenderer extends DefaultTableCellRenderer {
		DecimalFormat formatter;
		public DoubleRenderer(int digits) {
			super();
			char[] c = new char[digits];
			Arrays.fill(c,'0');
			formatter = new DecimalFormat("##0." + new String(c));
		}

		public void setValue(Object value) {
			setText((value == null) ? "" : formatter.format(value));
			setHorizontalAlignment(JLabel.CENTER);
		}
	}

	static class StringRenderer extends DefaultTableCellRenderer {
		public StringRenderer() { super(); } 

		public void setValue(Object value) {
			setText((value == null) ? "" : (String) value);
			setHorizontalAlignment(JLabel.CENTER);
		}
	}

	static class FunctionRenderer extends DefaultTableCellRenderer {
		public FunctionRenderer() { 
			super(); 
		} 

		public void setValue(Object value) {
			setHorizontalAlignment(JLabel.CENTER);
			if (value == null) {
				setText("");
				return;
			}
			int val = (int)((Double)value).doubleValue();
			if (val == 0) {
				setText("screened hydrogenic");
				return;
			}
			if (val == -1) {
				setText("from input data");
				return;
			}
			setText("");
			return;
		}
	}

	static class HeaderRenderer extends DefaultTableCellRenderer {
		TableCellRenderer defaultTCR;

		public HeaderRenderer(TableCellRenderer tcr) {
			super(); 
			defaultTCR = tcr;
		} 

		public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int column) {
			DefaultTableCellRenderer c = (DefaultTableCellRenderer)defaultTCR.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, column);
			c.setHorizontalAlignment(SwingConstants.CENTER);
			return c;
		}
	}
}
