/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.awt.font.*;
import java.awt.geom.*;

public class JButtonArray extends AbstractButton implements ActionListener {
	String[] buttonText;
	ButtonGroup buttonGroup;
	JToolBar bar;

	public JButtonArray() {
		super();
		setLayout(new BoxLayout(this, BoxLayout.LINE_AXIS));
		add(Box.createHorizontalGlue());
		add(bar = new JToolBar());
		bar.setFloatable(false);
//		bar.setBackground(Color.red);
		add(Box.createHorizontalGlue());
	}

	//addButtons
	public void addButtons(String[][] names, String[][] tips, String[][] commands, double rgbColors[][][], int defaultSelected) {
		int numRows, numCols, i, j;
		numRows = names.length;
		numCols = names[0].length;
		
		//specify layout in a grid
		bar.setLayout(new GridBagLayout());
		GridBagConstraints constraints = new GridBagConstraints();

		//create a ButtonGroup, and add buttons to it and the ButtonArray
		buttonGroup = new ButtonGroup();
		JToggleButton button;
		int n = 0;
		for (i=0; i<numRows; i++) {
			for (j=0; j<numCols; j++) {
				if (names[i][j] != null) {
					button = new JToggleButton(names[i][j]);
					button.setToolTipText(tips[i][j]);
					button.setMaximumSize(new Dimension(Short.MAX_VALUE,Short.MAX_VALUE));
					button.setPreferredSize(new Dimension(Short.MAX_VALUE,Short.MAX_VALUE));
					button.setFont(button.getFont().deriveFont(7.0f));
					button.setMargin(new Insets(-2,-2,-2,-2));
					button.setOpaque(true);
					Color color = new Color((float) rgbColors[i][j][0],(float) rgbColors[i][j][1],(float) rgbColors[i][j][2]);		
					button.setBackground(color);
					button.setActionCommand(commands[i][j]);
					button.setSelected(n == defaultSelected);
					button.setFocusPainted(false);
					button.addActionListener(this);
					constraints.gridx = j;
					constraints.gridy = i;
					constraints.weightx = 1;
					constraints.weighty = 1;
					constraints.fill = GridBagConstraints.BOTH;
					bar.add(button, constraints);
					buttonGroup.add(button);
					n++;
				} else {
					bar.add(new JLabel(""));
				}
			}
		}
		buttonText = new String[buttonGroup.getButtonCount()];
		i=0;
		for (Enumeration buttons = buttonGroup.getElements(); buttons.hasMoreElements();) {
			button = (JToggleButton)  buttons.nextElement();
			buttonText[i++] = button.getText();
		}
	}

/*
	public JButtonArray() {
		super();
		setLayout(new BoxLayout(this, BoxLayout.LINE_AXIS));
		add(Box.createHorizontalGlue());
		add(bar = new JToolBar());
		bar.setFloatable(false);
		bar.setBackground(Color.red);
		add(Box.createHorizontalGlue());
	}

	//addButtons
	public void addButtons(String[][] names, String[][] commands, double rgbColors[][][], int defaultSelected) {
		int numRows, numCols, i, j;
		numRows = names.length;
		numCols = names[0].length;
		
		//specify layout in a grid
		bar.setLayout(new GridLayout(numRows,numCols));

		//create a ButtonGroup, and add buttons to it and the ButtonArray
		buttonGroup = new ButtonGroup();
		JToggleButton button;
		int n = 0;
		for (i=0; i<numRows; i++) {
			for (j=0; j<numCols; j++) {
				if (names[i][j] != null) {
					button = new JToggleButton(names[i][j]);
					button.setMaximumSize(new Dimension(Short.MAX_VALUE,Short.MAX_VALUE));
					button.setPreferredSize(new Dimension(Short.MAX_VALUE,Short.MAX_VALUE));
					button.setFont(button.getFont().deriveFont(7.0f));
					button.setMargin(new Insets(-5,-5,-5,-5));
					button.setOpaque(true);
					Color color = new Color((float) rgbColors[i][j][0],(float) rgbColors[i][j][1],(float) rgbColors[i][j][2]);		
					button.setBackground(color);
					button.setActionCommand(commands[i][j]);
					button.setSelected(n == defaultSelected);
					button.setFocusPainted(false);
					button.addActionListener(this);
					bar.add(button);
					buttonGroup.add(button);
					n++;
				} else {
					bar.add(new JLabel(""));
				}
			}
		}
		buttonText = new String[buttonGroup.getButtonCount()];
		i=0;
		for (Enumeration buttons = buttonGroup.getElements(); buttons.hasMoreElements();) {
			button = (JToggleButton)  buttons.nextElement();
			buttonText[i++] = button.getText();
		}
	}
*/

	public Dimension getMaximumSize() {
		return getParent().getSize();
	}

	public void scaleTextSize() {
		JToggleButton button;
		Dimension size;
		Dimension maxSize = this.getMaximumSize();

		for (float s=20.0f; s>5.0f; s=s-0.5f) {
			for (Enumeration buttons = buttonGroup.getElements(); buttons.hasMoreElements();) {
				button = (JToggleButton) buttons.nextElement();
				button.setFont(button.getFont().deriveFont(s));
			}
		this.revalidate();
		size=this.getLayout().minimumLayoutSize(this);
		if(size.getWidth()<=maxSize.getWidth() && size.getHeight()<=maxSize.getHeight()) break;
		}
	}

	// actionPerformed: event handler
	public void actionPerformed(ActionEvent event) {
		fireActionPerformed(new ActionEvent(this, event.getID(), event.getActionCommand()));
	}
}
