/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import javax.swing.*;
import javax.swing.event.*;
import java.awt.event.*;
import java.util.Vector;
import java.util.Arrays;
import java.awt.font.*;
import java.awt.*;
import java.awt.geom.*;

public class OrbitalSelector extends AbstractButton implements ChangeListener {
	Vector<String> allLValues, lSpinnerList;
	JSpinner nSpinner, lSpinner;

	public OrbitalSelector() {
		setLayout(new BoxLayout(this, BoxLayout.LINE_AXIS));

		nSpinner = new JSpinner(new SpinnerNumberModel(1, 1, 9, 1));
		nSpinner.addChangeListener(this);
		setSizes(nSpinner,nSpinner.getPreferredSize());
		add(nSpinner);

		allLValues = new Vector<String>(Arrays.asList(ElectronSubshell.lValues));
		lSpinnerList = new Vector<String>(allLValues.subList(0,1));
		lSpinner = new JSpinner(new SpinnerListModel(lSpinnerList));
		lSpinner.addChangeListener(this);
		setSizes(lSpinner,addToDimension(lSpinner.getPreferredSize(),1,0));
		add(lSpinner);
	}

	public int getN() {
		return ((Integer)nSpinner.getValue()).intValue();
	}

	public String getLLetter() {
		return (String)lSpinner.getValue();
	}

	public int getLNumber() {
		return ElectronSubshell.fromSpecNotation(getLLetter());
	}

	public void setL(int L) {
		lSpinner.setValue(ElectronSubshell.toSpecNotation(L));
	}

	public String getOrbital() {
		return "" + getN() + getLLetter();
	}

	public void stateChanged(ChangeEvent event) {
		Object source = event.getSource();

		if (source == nSpinner) {
			int n = getN();
			int l = getLNumber();
			lSpinnerList.removeAllElements();
			lSpinnerList.addAll(allLValues.subList(0,Math.min(n,allLValues.size())));
			//just changing the list does not seem to work properly, at least under ubuntu, so we make a new model
			lSpinner.setModel(new SpinnerListModel(lSpinnerList));
			if (l < n) {setL(l);} else {setL(n-1);};
			this.revalidate();
			this.repaint();
		}

		fireActionPerformed(new ActionEvent(this, 0, ""));	
	}

	Dimension addToDimension(Dimension d, int dx, int dy) {
		return new Dimension(d.width+dx,d.height+dy);
	}
	
	void setSizes(JComponent c, Dimension d) {
		c.setMaximumSize(d);
		c.setMinimumSize(d);
		c.setPreferredSize(d);
	}	

}
