/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.awt.font.*;

public class PeriodicTableControl extends JButtonArray {
	
	final static String[][] names = {
		 {"H",  null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, "He"}, 
		 {"Li", "Be", null, null, null, null, null, null, null, null, null, null,  "B",  "C",  "N",  "O",  "F", "Ne"}, 
		 {"Na", "Mg", null, null, null, null, null, null, null, null, null, null, "Al", "Si",  "P",  "S", "Cl", "Ar"}, 
		 { "K", "Ca", "Sc", "Ti",  "V", "Cr", "Mn", "Fe", "Co", "Ni", "Cu", "Zn", "Ga", "Ge", "As", "Se", "Br", "Kr"}, 
		 {"Rb", "Sr",  "Y", "Zr", "Nb", "Mo", "Tc", "Ru", "Rh", "Pd", "Ag", "Cd", "In", "Sn", "Sb", "Te",  "I", "Xe"}, 
		 {"Cs", "Ba", "Lu", "Hf", "Ta",  "W", "Re", "Os", "Ir", "Pt", "Au", "Hg", "Tl", "Pb", "Bi", "Po", "At", "Rn"}, 
		 {"Fr", "Ra", "Lr", "Rf", "Db", "Sg", "Bh", "Hs", "Mt", null, null, null, null, null, null, null, null, null},
		 {null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null},
		 {null, null, "La", "Ce", "Pr", "Nd", "Pm", "Sm", "Eu", "Gd", "Tb", "Dy", "Ho", "Er", "Tm", "Yb", null, null}, 
		 {null, null, "Ac", "Th", "Pa",  "U", "Np", "Pu", "Am", "Cm", "Bk", "Cf", "Es", "Fm", "Md", "No", null, null}
	};
	
	final static String[][] numbers = {
		 {"1", null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, "2"}, 
		 {"3", "4", null, null, null, null, null, null, null, null, null, null, "5", "6", "7", "8", "9", "10"}, 
		 {"11", "12", null, null, null, null, null, null, null, null, null, null, "13", "14", "15", "16", "17", "18"}, 
		 {"19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36"}, 
		 {"37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", "53", "54"}, 
		 {"55", "56", "71", "72", "73", "74", "75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", "86"}, 
		 {"87", "88", "103", "104", "105", "106", "107", "108", "109", "110", "111", "112", null, null, null, null, null, null},
		 {null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null},	 
		 {null, null, "57", "58", "59", "60", "61", "62", "63", "64", "65", "66", "67", "68", "69", "70", null, null}, 
		 {null, null, "89", "90", "91", "92", "93", "94", "95", "96", "97", "98", "99", "100", "101", "102", null, null}
	};

	final static double[][][] colors = {	
		{{0.8, 1., 0.8}, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, {0.8, 1., 1.}}, {{0.8, 1., 0.8}, {0.8, 1., 0.8}, null, null, null, null, null, null, null, null, null, null, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}}, {{0.8, 1., 0.8}, {0.8, 1., 0.8}, null, null, null, null, null, null, null, null, null, null, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}}, {{0.8, 1., 0.8}, {0.8, 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}}, {{0.8, 1., 0.8}, {0.8, 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}}, {{0.8, 1., 0.8}, {0.8, 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}, {0.8, 1., 1.}}, {{0.8, 1., 0.8}, {0.8, 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, {1., 1., 0.8}, null, null, null, null, null, null}, {null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null}, {null, null, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, null, null}, {null, null, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, {1., 0.8, 0.8}, null, null}
	};

	public PeriodicTableControl() {
		super();
		String[][] tips = {
		 {"1", null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, "2"}, 
		 {"3", "4", null, null, null, null, null, null, null, null, null, null, "5", "6", "7", "8", "9", "10"}, 
		 {"11", "12", null, null, null, null, null, null, null, null, null, null, "13", "14", "15", "16", "17", "18"}, 
		 {"19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36"}, 
		 {"37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", "53", "54"}, 
		 {"55", "56", "71", "72", "73", "74", "75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", "86"}, 
		 {"87", "88", "103", "104", "105", "106", "107", "108", "109", "110", "111", "112", null, null, null, null, null, null},
		 {null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null},	 
		 {null, null, "57", "58", "59", "60", "61", "62", "63", "64", "65", "66", "67", "68", "69", "70", null, null}, 
		 {null, null, "89", "90", "91", "92", "93", "94", "95", "96", "97", "98", "99", "100", "101", "102", null, null}
	};
		int n;
		for (int i=0; i<numbers.length; i++) {
			for(int j=0; j<numbers[0].length; j++) {
				if (numbers[i][j] != null) {
					n = Integer.valueOf(numbers[i][j]).intValue();
					tips[i][j] = ElementsData.getName(n) + " Z = " + numbers[i][j];
				}
			}
		}
		addButtons(names, tips, numbers, colors, 2);
	}
}
