/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import java.util.Arrays;

public class Term {
	
	int L, multiplicity;
	static String[] specNotation = {"S", "P", "D", "F", "G", "H", "I", "K", "L", "M"};
	
	public Term() {
	}

	public Term(int multiplicity, int L) {
		this.multiplicity = multiplicity;
		this.L = L;
	}

	public Term(String multiplicity, String L) {
		this.multiplicity = new Integer(multiplicity).intValue();
		this.L = new Integer(L).intValue();
	}

	public Object clone() {
		Term c = new Term(multiplicity, L);
		return c;
	}

	public boolean equals(Term term) {
		return (L == term.L && multiplicity == term.multiplicity);
	}

	public void setMultiplicity(String multiplicity) {
		this.multiplicity = new Integer(multiplicity).intValue();
	}

	public void setL(String L) {
		this.L = new Integer(L).intValue();
	}

	// getMultiplicity
	public int getMultiplicity() {
		return multiplicity;
	}

	// getL
	public int getL() {
		return L;
	}

	public void setToGroundState(int atomicNumber) {
		String term = ElementsData.getTerm(atomicNumber);
		setMultiplicity(term.substring(0,1));
		L = fromSpecNotation(term.substring(1,2));
	}

	public String toString() {
		return String.valueOf(multiplicity) + toSpecNotation(L);
	}

	public String toHTMLString() {
		return "<sup>" + String.valueOf(multiplicity) + "</sup>" + toSpecNotation(L);
	}

	static String toSpecNotation(int L) {
		if (L < specNotation.length)
			return specNotation[L];
		else
			return "Z";
	}

	static int fromSpecNotation(String L) {
		for (int i=0; i<specNotation.length; i++) {
			if (L.equals(specNotation[i])) return i;
		}
		return -1;
	}
}
