/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfapplet;

import edu.berkeley.eecs.ptolemy.plot.*;
import java.awt.*;
import java.awt.image.BufferedImage;

public class WFPlot extends Plot {

	public WFPlot() {
		super();
		setXLabel("r (a.u.)");
		setYLabel("P(r)");
		setTitle("Wavefunctions");
		setBackground(null);
	}

	public void clearData() {
		clear(false);
		clearLegends();
	}

	public void plotData(double[][] data, double[] radii, String[] labels, int[] toShow) {
		clearData();

		//All plots start at (0,0)
		for (int j=0; j<toShow.length; j++) {
			addPoint(toShow[j],0,0,true);
		}

		//plot wavefunction data
		double maxY = 0;
		double minY = 0;
		double newY = 0;
		double newX = 0;
		for (int i=0; i<data[0].length; i++) {
			newX = data[0][i];
			for (int j=0; j<toShow.length; j++) {
				newY = data[toShow[j]+1][i];
				if (newY > maxY) maxY = newY;
				if (newY < minY) minY = newY;
				addPoint(toShow[j],newX,newY,true);
			}
		}

		//work backwards to find the x value where all the plots have fallen to %20
		search:
		for (int i=data[0].length-1; i>=0; i--) {
			newX = data[0][i];
			for (int j=0; j<toShow.length; j++) {
				newY = data[toShow[j]+1][i];
				if (newY > .2*maxY) break search;
				if (newY < .2*minY) break search;
			}
		}
		
		//add average radius markers
		if (radii != null) {
			double r;
			for (int j=0; j<toShow.length; j++) {
				r = radii[toShow[j]];
				addPoint(toShow[j],r,minY,false);
				addPoint(toShow[j],r,maxY,true);
				if (newX < r) newX = r;
			}
		}

		//scale plot
		setXRange(0,newX);
		setYRange(minY,maxY);

		//add labels to legend
		for (int j=0; j<toShow.length; j++) {
			addLegend(toShow[j],labels[toShow[j]]);
		}
		repaint();

		
//		System.out.println(getGraphics());
//		getGraphics().clearRect(0,0,400,400);
//		System.out.println(getGraphics());

//        Rectangle bounds = getBounds();
//        BufferedImage newPlotImage = new BufferedImage(
//                    bounds.width, bounds.height,
//                    BufferedImage.TYPE_3BYTE_BGR);
//        Graphics2D offScreenGraphics = newPlotImage.createGraphics();
//        super.super.super.paintComponent(offScreenGraphics);
//       offScreenGraphics.drawRect(10,10,100,100);
//        getGraphics().drawImage(newPlotImage, 0, 0, null);

//		repaint();
	}

	protected synchronized void _drawPlot(Graphics graphics,
        boolean clearfirst, Rectangle drawRectangle) {
		Graphics2D g2 = (Graphics2D) graphics;

		//turn on antialiasing
		g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
		super._drawPlot(g2, clearfirst, drawRectangle);
    }
}
	
