/********************************
* This file is part of HFApplet, copyright (C) 2005 Simon Rochester and John C. Morrison
*
* HFApplet is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* HFApplet is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************/

package edu.louisville.physics.jcm.hfserver;

import java.net.*;
import java.io.*;
import java.util.*;

public class HFConnection extends Thread {
	private Socket clientSocket = null;

	public HFConnection(Socket socket) {
		super("HFConnection");
		clientSocket = socket;
		System.out.println("Connection to " + clientSocket.getInetAddress().toString() + " established on: " + new Date());
	}

	public void run() { 
		PrintWriter toClient = null;
		BufferedReader fromClient = null;
		PrintWriter toProcess = null;
		BufferedReader fromProcess = null;
		Process hfProcess = null;

		try	{
			for (;;) {
				//create input and output streams for communicating with the client
				toClient = new PrintWriter(clientSocket.getOutputStream(), true);
				fromClient = new BufferedReader(new InputStreamReader(clientSocket.getInputStream()));

				//start HF process "hf.exe"
				Runtime runtime = Runtime.getRuntime();
				hfProcess = runtime.exec("bin/HF");
	//			hfProcess = runtime.exec("C:\\win32app\\salford\\sdbg.exe HF");
				System.out.println("Started process: " + hfProcess);
			
				//create input and output streams for communicating with the process
				toProcess = new PrintWriter(hfProcess.getOutputStream(), true);
				fromProcess = new BufferedReader(new InputStreamReader(hfProcess.getErrorStream()));

				String line;
				troll:
				for (;;) {
					//read data from the client and feed it to the process
					while ((line = fromClient.readLine()) != null && !line.equals("END")) {
						if (line.equals("RESTART") || line.equals("EXIT")) break troll;
			//			System.out.println(line);
						toProcess.println(line);
					}
					if (line == null) break troll;
					
					//read data from the process and feed it to the client
					while (!(line = fromProcess.readLine()).equals(" END")) {
			//			System.out.println(line);
						toClient.println(line);
						if (line.equals(" END OF CASE")) break troll;
					}
					toClient.println("END");
				}

				System.out.println("Ending process: " + hfProcess);
				hfProcess.destroy();
				if (line == null || line.equals("EXIT") || line.equals(" END OF CASE")) break;
			}
		} catch (IOException e)	{
			//exception handling
			System.err.println(e.toString());
		} finally {
			try {
				//cleanup
				System.out.println("Closing connection to " + clientSocket.getInetAddress().toString());
				if (hfProcess != null) hfProcess.destroy();
				if (toClient != null) toClient.close();
				if (fromClient != null) fromClient.close();
				if (toProcess != null) toProcess.close();
				if (fromProcess != null) fromProcess.close();
				if (clientSocket != null) clientSocket.close();
			} catch (IOException e)	{
				System.err.println(e.toString());
			}
		}
	}
}
