/*
 *  Produced by f2java.  f2java is part of the Fortran-
 *  -to-Java project at the University of Tennessee Netlib
 *  numerical software repository.
 *
 *  Original authorship for the BLAS and LAPACK numerical
 *  routines may be found in the Fortran source, available at
 *  http://www.netlib.org.
 *
 *  Fortran input file: HF_f2j.f
 *
 */

import java.lang.*;
import org.netlib.util.*;



public class Hf {

// *     ------------------------------------------------------------------
// *
// *     A GENERAL HARTREE-FOCK PROGRAM
// *
// *     by C. Froese Fischer
// *        Vanderbilt University
// *        Nashville, TN 37235 USA
// *
// *     April, 1987
// *     Published in Computer Physics Communications, 43 (1987) 355
// *
// *     .... Modified for for arbitrarily filled f-shells
// *     by Gediminas GAIGALAS 
// *        Institute of Theoretical Physics and Astronomy
// *        A. Gostauto str. 12
// *        Vilnius, 2600, Lithuania
// *
// *     January, 1996
// *
// *     Pulished in Computer Physics Communications, 98 (1996) 255
// *
// *     .... modified for use with java applet
// *     by Simon Rochester
// *
// *
// * -------------------------------------------------------------------
// *
// *     All comments in the program listing assume the radial function P
// *     is the solution of an equation of the form
// *
// *      P" + ( 2Z/R - Y - L(L+1)/R**2 - E)P = X + T
// *
// *     where Y is called a potential function
// *           X is called an exchange function, and
// *           T includes contributions from off-diagonal energy parameter

// *
// *     The program uses LOG(Z*R) as independent variable and
// *                      P/SQRT(R) as dependent variable.
// *     As a result all equations must be transformed as described in
// *     Sec. 6-2 and 6-4 of the book - ``The Hartree-Fock Method for
// *     Atoms'',Wiley Interscience, 1977, by Charlotte FROESE FISCHER.
// *     (All references to equations and sections refer to this book.)
// *
// *     Numerical procedures are the same as those for MCHF and are
// *     described in Computer Physics Reports, Vol. 3, 273--326 (1986).
// *     ------------------------------------------------------------------
// *       M A I N    P R O G R A M
// *     ------------------------------------------------------------------
// *
// *       The MAIN program controls the overall calculation  that
// *   may  consist  of  a  series of atoms or ions in an iso-electronic
// *   sequence.  Initial  estimates  for  the first are obtained either
// *   from a file WFN.INP, if it exists, and scaled for the appropriate
// *   Z, if necessary, or from a screened hydrogenic approximation.  All
// *   others are  obtained  by  scaling  the previous results using the
// *   scaling of Sec.  (7-2).
// *
// *
// *
// *  *****  Unit designators for input and output files
// *  IUF Input file --- if exists, set to 21
// *  OUF Output file --- set to 31
// *  LOGF Log file --- set to 3 when writing to file,
// *	standard output 2 to communicate with applet
// *
public static String aster = new String("*");
// *
// *  *****  WRITE OUT HEADER
// *

public static void main (String [] args)  {

boolean print= false;
boolean strong= false;
String ans= new String(" ");
boolean old= false;
doubleW erel= new doubleW(0.0d);
doubleW etotal= new doubleW(0.0d);
double scftol= 0.0d;
double zz= 0.0d;
int i= 0;
int j= 0;
  EasyIn __f2j_stdin = new EasyIn();
  java.util.Vector __io_vec = new java.util.Vector();
__io_vec.clear();
Util.f77write("///////22X,'===============================',/22X,' H A R T R E E - F O C K . 04.1',/22X,'==============================='", __io_vec);
label9:
   Dummy.label("Hf",9);
// *
// *  *****  WRITE OUT DIMENSION INFORMATION
// *
__io_vec.clear();
  __io_vec.addElement(new String("NWF"));
  __io_vec.addElement(new Integer(20));
  __io_vec.addElement(new String("NO"));
  __io_vec.addElement(new Integer(220));
Util.f77write("//15X,'THE DIMENSIONS FOR THE CURRENT VERSION ARE:'/13X,2(10X,2(A6,'=',I3,4X)/)/", __io_vec);
label99:
   Dummy.label("Hf",99);
// *
// *  *****  INITIALIZE
// *
Init.init();
// *
// *  ***** SET UNIT NUMBERS AND OPEN FILES
// *
label1:
   Dummy.label("Hf",1);
__io_vec.clear();
  __io_vec.addElement(new String(" START OF CASE"));
  __io_vec.addElement(new String(" ============="));
Util.f77write(null, __io_vec);
// *      INQUIRE(FILE='wfn.inp',EXIST=OLD)
// *      IF (OLD) THEN
HF_f2j_inout.iuf.val = 1;
// *         OPEN(UNIT=IUF,FILE='wfn.inp',STATUS='OLD',
// *     :        FORM='UNFORMATTED')
// *      ELSE
// *         IUF = 0
// *      END IF
// *      OUF = 0
HF_f2j_inout.ouf.val = 31;
// *      OPEN(UNIT=OUF,FILE='wfn.out',STATUS='UNKNOWN',FORM='UNFORMATTED')
// *      LOGF = 2
// *     OPEN(UNIT=LOGF,FILE='hf.log',STATUS='UNKNOWN')
// *
HF_f2j_test.fail.val = false;
{
for (i = 1; i <= (20); i++) {
Dpm.dpm(i) = HF_f2j_param.d10.val;
{
for (j = 1; j <= (20); j++) {
HF_f2j_wave.e[(i-(1))+(j-(1)) * (20)] = HF_f2j_param.d0.val;
Dummy.label("Hf",4);
}              //  Close for() loop. 
}
Dummy.label("Hf",4);
}              //  Close for() loop. 
}
// *
// *  *****  DETERMINE DATA ABOUT THE PROBLEM
// *
Data.data();
// *
// *  *****  SET PARAMETERS TO THEIR DEFAULT VALUE
// *
label13:
   Dummy.label("Hf",13);
print = true;
scftol = 1.e-8;
HF_f2j_param.nscf.val = 12;
HF_f2j_param.ic.val = (2+((((HF_f2j_param.nwf.val+1)-HF_f2j_param.ib.val))/4));
HF_f2j_test.trace.val = false;
if ((HF_f2j_param.ib.val <= HF_f2j_param.nwf.val))  {
    __io_vec.clear();
  __io_vec.addElement(new String(" Default values for remaining parameters? (Y/N/H) "));
Util.f77write(null, __io_vec);
ans = __f2j_stdin.readChars(1);
__f2j_stdin.skipRemaining();
if (((ans.regionMatches(0, "H", 0, 1) ) || (ans.regionMatches(0, "h", 0, 1) )))  {
    Help.help(4);
Dummy.go_to("Hf",13);
}
if (((!ans.regionMatches(0, "Y", 0, 1) ) && (!ans.regionMatches(0, "y", 0, 1) )))  {
    // *
// *  *****  ADDITIONAL PARAMETERS
// *
label50:
   Dummy.label("Hf",50);
__io_vec.clear();
  __io_vec.addElement(new String(" Default values (NO,STRONG) ? (Y/N/H) "));
Util.f77write(null, __io_vec);
ans = __f2j_stdin.readChars(1);
__f2j_stdin.skipRemaining();
if (((ans.regionMatches(0, "H", 0, 1) ) || (ans.regionMatches(0, "h", 0, 1) )))  {
    Help.help(3);
Dummy.go_to("Hf",50);
}
if (((!ans.regionMatches(0, "Y", 0, 1) ) && (!ans.regionMatches(0, "y", 0, 1) )))  {
    __io_vec.clear();
  __io_vec.addElement(new String(" Enter values in FORMAT(I3,1X,L1) "));
Util.f77write(null, __io_vec);
HF_f2j_param.no.val = __f2j_stdin.readInt();
strong = __f2j_stdin.readBoolean();
__f2j_stdin.skipRemaining();
if ((HF_f2j_param.no.val > (220)))  {
    __io_vec.clear();
  __io_vec.addElement(new String(" TOO MANY POINTS: the allowed"));
  __io_vec.addElement(new String(" MAXIMUM is "));
  __io_vec.addElement(new Integer(220));
Util.f77write(null, __io_vec);
Dummy.go_to("Hf",50);
}
HF_f2j_param.nd.val = (HF_f2j_param.no.val-2);
HF_f2j_test.omit.val = (!strong);
}
label16:
   Dummy.label("Hf",16);
__io_vec.clear();
  __io_vec.addElement(new String(" Default values for PRINT, SCFTOL ? (Y/N/H)"));
Util.f77write(null, __io_vec);
ans = __f2j_stdin.readChars(1);
__f2j_stdin.skipRemaining();
if (((ans.regionMatches(0, "H", 0, 1) ) || (ans.regionMatches(0, "h", 0, 1) )))  {
    Help.help(5);
Dummy.go_to("Hf",16);
}
if (((!ans.regionMatches(0, "Y", 0, 1) ) && (!ans.regionMatches(0, "y", 0, 1) )))  {
    __io_vec.clear();
  __io_vec.addElement(new String(" Input FORMAT(L1, 1X, E6.1) "));
Util.f77write(null, __io_vec);
print = __f2j_stdin.readBoolean();
scftol = __f2j_stdin.readDouble();
__f2j_stdin.skipRemaining();
}
label17:
   Dummy.label("Hf",17);
__io_vec.clear();
  __io_vec.addElement(new String(" Default values for NSCF, IC ? (Y/N/H) "));
Util.f77write(null, __io_vec);
ans = __f2j_stdin.readChars(1);
__f2j_stdin.skipRemaining();
if (((ans.regionMatches(0, "H", 0, 1) ) || (ans.regionMatches(0, "h", 0, 1) )))  {
    Help.help(6);
Dummy.go_to("Hf",17);
}
if (((!ans.regionMatches(0, "Y", 0, 1) ) && (!ans.regionMatches(0, "y", 0, 1) )))  {
    __io_vec.clear();
  __io_vec.addElement(new String(" Input FORMAT(I2, 1X, I1) "));
Util.f77write(null, __io_vec);
HF_f2j_param.nscf.val = __f2j_stdin.readInt();
HF_f2j_param.ic.val = __f2j_stdin.readInt();
__f2j_stdin.skipRemaining();
}
label18:
   Dummy.label("Hf",18);
__io_vec.clear();
  __io_vec.addElement(new String(" Default values for TRACE ? (Y/N/H) "));
Util.f77write(null, __io_vec);
ans = __f2j_stdin.readChars(1);
__f2j_stdin.skipRemaining();
if (((ans.regionMatches(0, "H", 0, 1) ) || (ans.regionMatches(0, "h", 0, 1) )))  {
    Help.help(7);
Dummy.go_to("Hf",18);
}
if (((ans.regionMatches(0, "N", 0, 1) ) || (ans.regionMatches(0, "n", 0, 1) ))) {
    HF_f2j_test.trace.val = true;
}
    }
}
// *
// *
// *  *****  PERFORM THE MCHF ITERATION
// *
Scf.scf(etotal,scftol,erel);
// *
// *  *****  OUTPUT RESULTS IF PRINT = .TRUE.
// *
Output.output(print);
label15:
   Dummy.label("Hf",15);
if (HF_f2j_test.fail.val) {
    Dummy.go_to("Hf",6);
}
    Summry.summry(etotal.val,erel.val);
label19:
   Dummy.label("Hf",19);
__io_vec.clear();
  __io_vec.addElement(new String(" Additional parameters ? (Y/N/H) "));
Util.f77write(null, __io_vec);
ans = __f2j_stdin.readChars(1);
__f2j_stdin.skipRemaining();
if (((ans.regionMatches(0, "H", 0, 1) ) || (ans.regionMatches(0, "h", 0, 1) )))  {
    Help.help(8);
Dummy.go_to("Hf",19);
}
if (((ans.regionMatches(0, "Y", 0, 1) ) || (ans.regionMatches(0, "y", 0, 1) ))) {
    Menu.menu();
}
    // *
// *  *****  CHECK FOR ISOELECTRONIC SEQUENCE OR END OF CASE.
// *
label20:
   Dummy.label("Hf",20);
__io_vec.clear();
  __io_vec.addElement(new String(" Do you wish to continue along the sequence ? "));
Util.f77write(null, __io_vec);
ans = __f2j_stdin.readChars(1);
__f2j_stdin.skipRemaining();
if (((ans.regionMatches(0, "H", 0, 1) ) || (ans.regionMatches(0, "h", 0, 1) )))  {
    Help.help(9);
Dummy.go_to("Hf",20);
}
if (((ans.regionMatches(0, "Y", 0, 1) ) || (ans.regionMatches(0, "y", 0, 1) )))  {
    __io_vec.clear();
  __io_vec.addElement(new String("   Enter: ATOM, ZZ, (ACC(I),I=1,NWF) in "));
  __io_vec.addElement(new String(" format(A6,F6.0,(20F3.1))"));
Util.f77write(null, __io_vec);
HF_f2j_label.atom.val = __f2j_stdin.readChars(6);
zz = __f2j_stdin.readDouble();
for(i = 1; i <= HF_f2j_param.nwf.val; i++)
{
Acc.acc(i) = __f2j_stdin.readInt();
}
__f2j_stdin.skipRemaining();
// *
// *  *****  SCALE RESULTS FOR ANOTHER MEMBER OF THE ISOELECTRONIC SEQUENCE
// *
Scaler.scaler(zz);
__io_vec.clear();
  __io_vec.addElement(new String(HF_f2j_label.atom.val));
  __io_vec.addElement(new String(HF_f2j_label.term.val));
Util.f77write("1h1,9X,2A6", __io_vec);
label14:
   Dummy.label("Hf",14);
Orthog.orthog();
Dummy.go_to("Hf",13);
}
// *
// *  *****  DETERMINE END OF CASE
// *
label6:
   Dummy.label("Hf",6);
__io_vec.clear();
  __io_vec.addElement(new String(" END OF CASE"));
  __io_vec.addElement(new String(" ==========="));
Util.f77write(null, __io_vec);
System.exit(0);
Dummy.label("Hf",999999);
return;
   }
} // End class.
